Index: src/serialize.cc |
diff --git a/src/serialize.cc b/src/serialize.cc |
index eeb180ac324783dd34cfa3335bea04ba068f8c95..10873b9188a03e8ff99aee16ce1c2893e0a76c85 100644 |
--- a/src/serialize.cc |
+++ b/src/serialize.cc |
@@ -1355,9 +1355,9 @@ void PartialSerializer::SerializeObject( |
// should go through the root array or through the partial snapshot cache. |
// If this is not the case you may have to add something to the root array. |
ASSERT(!startup_serializer_->address_mapper()->IsMapped(heap_object)); |
- // All the symbols that the partial snapshot needs should be either in the |
- // root table or in the partial snapshot cache. |
- ASSERT(!heap_object->IsSymbol()); |
+ // All the internalized strings that the partial snapshot needs should be |
+ // either in the root table or in the partial snapshot cache. |
+ ASSERT(!heap_object->IsInternalizedString()); |
if (address_mapper_.IsMapped(heap_object)) { |
int space = SpaceOfObject(heap_object); |